export default {
    "message": "Unexpected token }",
    "column": 29,
    "index": 28,
    "lineNumber": 1
}